@@ -5,68 +5,55 @@
 # Licence GPL v3
 
 
-
-
-setMethod('merge', signature(x='list', y='missing'), 
+setMethod('merge', signature(x='Raster', y='Raster'), 
 function(x, y, ..., tolerance=0.05, filename="", format, overwrite, progress) { 
 	
-	filename <- trim(filename)
+	x <- c(x, y, list(...))
 	if (missing(format)) { format <- .filetype(format=format, filename=filename) } 
-	if (missing(overwrite)) {	overwrite <- .overwrite() }
+	if (missing(overwrite)) { overwrite <- .overwrite()	}
 	if (missing(progress)) { progress <- .progress() }
 	
+	merge(x, tolerance=tolerance, filename=filename, format=format, overwrite=overwrite, progress=progress, test=FALSE)
 	
-	if (! all(sapply(x, function(x) inherits(x, 'Raster')))) {
-		stop('elements of "x" should all inherit from RasterLayer')
-	}
-	
-	do.call(merge, x, tolerance=tolerance, filename=filename, format=format, overwrite=overwrite, progress=progress)
 } )
 
 
 
-setMethod('merge', signature(x='Raster', y='Raster'), 
-function(x,y,..., tolerance=0.05, filename="", format, overwrite, progress){ 
+setMethod('merge', signature(x='list', y='missing'), 
+function(x, y,..., tolerance=0.05, filename="", format, overwrite, progress, test=TRUE){ 
 
+	s <- sapply(x, function(x) inherits(x, 'Raster'))
+	x <- x[s]
+
+	if (length(x) < 2) {
+		stop('merge needs at least 2 Raster* objects')
+	}
+	
+	nl <- unique(sapply(x, nlayers))
+	if (length(nl) != 1) {
+		# to do, recycling, should be OK of one of the two has a single layer
+		stop( 'different number of layers' )
+	}
+	compare(x, extent=FALSE, rowcol=FALSE, orig=TRUE, res=TRUE, tolerance=tolerance)
+	
 	filename <- trim(filename)
 	if (missing(format)) { format <- .filetype(format=format, filename=filename) } 
 	if (missing(overwrite)) { overwrite <- .overwrite()	}
 	if (missing(progress)) { progress <- .progress() }
 
-	nl <- nlayers(x)
-	if (nlayers(x) != nlayers(y)) {
-		# should be OK of one of the two has a single layer
-		stop( 'nlayers(x) != nlayers(y)' )
-	}
 
-	rasters <- c(x, y)
-	dots <- list(...)
-	dots <- unlist(dots) # make simple list
-	if (length(dots) > 0) {
-		for (i in 1:length(dots)) {
-			if ( inherits( dots[[i]], 'Raster' ) ) {
-				if ( nl != nlayers(dots[[i]]) ) {
-					# should be OK of one of the two has a single layer
-					stop( 'nlayers of layers not equal' )
-				}
-				rasters <- c(rasters, dots[[i]])
-			}
-		}
-	}
-
-	compare(rasters, extent=FALSE, rowcol=FALSE, orig=TRUE, res=TRUE, tolerance=tolerance)
-	bb <- unionExtent(rasters)
+	bb <- unionExtent(x)
 	
-	if (nlayers(x) > 1) {
-		outRaster <- brick(rasters[[1]], values=FALSE)
+	if (nl > 1) {
+		outRaster <- brick(x[[1]], values=FALSE)
 	} else {
-		outRaster <- raster(rasters[[1]])
+		outRaster <- raster(x[[1]])
 	}
 	outRaster <- setExtent(outRaster, bb, keepres=TRUE, snap=FALSE)
 
 	datatype <- 'INT4S'
-	for (i in 1:length(rasters)) {
-		dtype <- .shortDataType(dataType(rasters[[i]]))
+	for (i in 1:length(x)) {
+		dtype <- .shortDataType(dataType(x[[i]]))
 		if (any(dtype == 'FLT')) {
 			datatype <- 'FLT4S'
 		}	
@@ -74,20 +61,20 @@ function(x,y,..., tolerance=0.05, filename="", format, overwrite, progress){
 
 	if ( canProcessInMemory(outRaster, 3) ) {
 		if (nl > 1) {
-			v = matrix(NA, nrow=ncell(outRaster), ncol=nlayers(x))
-			for (i in 1:length(rasters)) {
-				cells <- cellsFromExtent( outRaster, extent(rasters[[i]]) )
+			v = matrix(NA, nrow=ncell(outRaster), ncol=nl)
+			for (i in 1:length(x)) {
+				cells <- cellsFromExtent( outRaster, extent(x[[i]]) )
 				vv <- v[cells, ]
 				na = as.logical( apply(vv, 1, FUN=function(x) sum(is.na(x))==nl) )
-				vv[na, ] <- getValues(rasters[[i]])[na, ]
+				vv[na, ] <- getValues(x[[i]])[na, ]
 				v[cells, ] <- vv
 			}
 		} else {
 			v = rep(NA, ncell(outRaster))
-			for (i in 1:length(rasters)) {
-				cells = cellsFromExtent( outRaster, extent(rasters[[i]]) )
+			for (i in 1:length(x)) {
+				cells = cellsFromExtent( outRaster, extent(x[[i]]) )
 				vv = v[cells]
-				vv[is.na(vv)] = getValues(rasters[[i]])[is.na(vv)]
+				vv[is.na(vv)] = getValues(x[[i]])[is.na(vv)]
 				v[cells] = vv
 			}
 		}
@@ -100,10 +87,10 @@ function(x,y,..., tolerance=0.05, filename="", format, overwrite, progress){
 	}
 	
 	
-	rowcol <- matrix(0, ncol=3, nrow=length(rasters))
-	for (i in 1:length(rasters)) {
-		xy1 <- xyFromCell(rasters[[i]], 1) # first row/col on old raster[[i]]
-		xy2 <- xyFromCell(rasters[[i]], ncell(rasters[[i]]) ) #last row/col on old raster[[i]]
+	rowcol <- matrix(0, ncol=3, nrow=length(x))
+	for (i in 1:length(x)) {
+		xy1 <- xyFromCell(x[[i]], 1) # first row/col on old raster[[i]]
+		xy2 <- xyFromCell(x[[i]], ncell(x[[i]]) ) #last row/col on old raster[[i]]
 		rowcol[i,1] <- rowFromY(outRaster, xy1[2]) #start row on new raster
 		rowcol[i,2] <- rowFromY(outRaster, xy2[2]) #end row
 		rowcol[i,3] <- colFromX(outRaster, xy1[1]) #start col
@@ -121,10 +108,10 @@ function(x,y,..., tolerance=0.05, filename="", format, overwrite, progress){
 		rd <- rep(NA, outRaster@ncols) 
 		for (r in 1:nrow(outRaster)) {
 			rd[] <- NA
-			for (i in length(rasters):1) {  #reverse order so that the first raster covers the second etc.
+			for (i in length(x):1) {  #reverse order so that the first raster covers the second etc.
 				if (r >= rowcol[i,1] & r <= rowcol[i,2]) { 
-					d <- getValues(rasters[[i]], r + 1 - rowcol[i,1]) 
-					id2 <- seq(1:ncol(rasters[[i]])) + rowcol[i,3] - 1
+					d <- getValues(x[[i]], r + 1 - rowcol[i,1]) 
+					id2 <- seq(1:ncol(x[[i]])) + rowcol[i,3] - 1
 					d <- cbind(id2, d)
 					d <- na.omit(d)
 					rd[d[,1]] <- d[,2]
@@ -139,10 +126,10 @@ function(x,y,..., tolerance=0.05, filename="", format, overwrite, progress){
 		rd <- matrix(nrow=ncol(outRaster), ncol=nl) 
 		for (r in 1:nrow(outRaster)) {
 			rd[] <- NA
-			for (i in length(rasters):1) {  #reverse order so that the first raster covers the second etc.
+			for (i in length(x):1) {  #reverse order so that the first raster covers the second etc.
 				if (r >= rowcol[i,1] & r <= rowcol[i,2]) { 
-					d <- getValues(rasters[[i]], r + 1 - rowcol[i,1]) 
-					id2 <- seq(1:ncol(rasters[[i]])) + rowcol[i,3] - 1
+					d <- getValues(x[[i]], r + 1 - rowcol[i,1]) 
+					id2 <- seq(1:ncol(x[[i]])) + rowcol[i,3] - 1
 					d <- cbind(id2, d)
 					d <- na.omit(d)
 					rd[d[,1], ] <- d[ , -1]
@@ -154,7 +141,7 @@ function(x,y,..., tolerance=0.05, filename="", format, overwrite, progress){
 		pbClose(pb)
 		outRaster <- writeStop(outRaster)
 	}
-	layerNames(outRaster) <- paste(layerNames(x), '(merged)')
+	layerNames(outRaster) <- paste(layerNames(x[[1]]), '(merged)')
 	return(outRaster)
 }
 )
